package e1;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JTextField;

@SuppressWarnings("serial")
public class TempConverter extends JFrame {

	private JLabel labelC; // Name of the Celsius field
	private JLabel labelF; // Name of the Fahrenheit field
	private JTextField textFieldC; // Celsius field
	private JTextField textFieldF; // Fahrenheit field
	private JButton buttonReset; // Button for reseting the fields
	private JButton buttonClose; // Button for closing the window

	/*
	 * Listener of the Celsius field: convert the data from Celsius to
	 * Fahrenheit when the "enter" keyboard button is hit (in the Celsius field)
	 */
	private ActionListener textFieldCListener = new ActionListener() {
		public void actionPerformed(ActionEvent e) {
			String value = textFieldC.getText();
			try {
				float valC = new Float(value);
				float valF = valC * 1.8f + 32;
				textFieldF.setText(Float.toString(valF));
			} catch (Exception exp) {
				textFieldF.setText("");
				textFieldC.setText("");
			}
		}
	};

	/*
	 * Listener of the Fahrenheit field: Convert the data from Fahrenheit to
	 * Celsius when the "enter" keyboard button is hit (in the Fahrenheit field)
	 */
	/*private ActionListener textFieldFListener = new ActionListener() {
		public void actionPerformed(ActionEvent e) {
			String value = textFieldF.getText();
			try {
				float valF = new Float(value);
				float valC = (valF - 32) / 1.8f;
				textFieldC.setText(Float.toString(valC));
			} catch (Exception exp) {
				textFieldF.setText("");
				textFieldC.setText("");
			}
		}
	};*/
	
	private KeyListener textFieldFListener = new KeyListener() {
		
		@Override
		public void keyTyped(KeyEvent e) {}
		
		@Override
		public void keyReleased(KeyEvent e) {
			String value = textFieldF.getText();
			try {
				float valF = new Float(value);
				float valC = (valF - 32) / 1.8f;
				textFieldC.setText(Float.toString(valC));
			} catch (Exception exp) {
				textFieldF.setText("");
				textFieldC.setText("");
			}
		}
		
		@Override
		public void keyPressed(KeyEvent e) {}
	};
	
	/*
	 * Listener of the Reset button: Reset the value in the text field when the
	 * Reset button is pressed
	 */
	private ActionListener buttonResetListener = new ActionListener() {
		public void actionPerformed(ActionEvent e) {
			textFieldF.setText("");
			textFieldC.setText("");
		}
	};

	/*
	 * Listener of the Close button: Close the program window when the Close
	 * button is pressed
	 */
	private ActionListener buttonCloseListener = new ActionListener() {
		public void actionPerformed(ActionEvent e) {
			dispose();
		}
	};

	/**
	 * Constructor of the temperature converter
	 * 
	 * @param title Title of the window
	 */
	public TempConverter(String title) {
		super(title);
		init();
	}

	/**
	 * Initialize the converter window
	 */
	public void init() {
		// Create the labels
		labelC = new JLabel("Celsius");
		labelF = new JLabel("Fahrenheit");

		// Create the text fields
		textFieldC = new JTextField(15);
		textFieldC.setAlignmentX(LEFT_ALIGNMENT);
		textFieldC.addActionListener(textFieldCListener);
		textFieldF = new JTextField(15);
		textFieldF.setAlignmentX(LEFT_ALIGNMENT);
		//textFieldF.addActionListener(textFieldFListener);
		textFieldF.addKeyListener(textFieldFListener);

		// Create the two columns for Celsius and Fahrenheit
		JPanel paneC = new JPanel();
		paneC.setLayout(new BoxLayout(paneC, BoxLayout.Y_AXIS));
		paneC.add(labelC);
		paneC.add(textFieldC);

		JPanel paneF = new JPanel();
		paneF.setLayout(new BoxLayout(paneF, BoxLayout.Y_AXIS));
		paneF.add(labelF);
		paneF.add(textFieldF);

		// Combine the two columns in a temperature panel
		JPanel tempPane = new JPanel();
		tempPane.add(paneC);
		tempPane.add(paneF);

		// Create the button
		buttonReset = new JButton("Reset");
		buttonReset.addActionListener(buttonResetListener);
		buttonClose = new JButton("Close");
		buttonClose.addActionListener(buttonCloseListener);

		// Create the button panel
		JPanel buttonPane = new JPanel();
		buttonPane.setLayout(new BoxLayout(buttonPane, BoxLayout.X_AXIS));
		buttonPane.setBorder(BorderFactory.createEmptyBorder(5, 10, 10, 10));
		buttonPane.add(Box.createHorizontalGlue());
		buttonPane.add(buttonReset);
		buttonPane.add(Box.createRigidArea(new Dimension(10, 0)));
		buttonPane.add(buttonClose);

		// Add the temperature panel and the
		// button panel to the main panel
		Container mainPane = getContentPane();
		mainPane.setLayout(new BorderLayout());
		mainPane.add(tempPane, BorderLayout.CENTER);
		mainPane.add(buttonPane, BorderLayout.SOUTH);

		// Resize window and make it visible
		pack();
		setVisible(true);
		// Close the application when the user closes the window
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	public static void main(String[] args) {
		new TempConverter("Temperature converter");
	}

}
